@@ -258,6 +258,8 @@ class Saera:
 			#Espeak makes a poor guess how to pronounce this, so we help it out.
 			result = result.replace("maemo","maymo")
 			result = result.replace("I am.","Ay am.")
+			result = result.replace("sushi", "sooshi")
+			result = result.replace("falafel", "fuh-laHfel")
 			gobject.timeout_add(100, os.system, saera_processing.sent.espeak_cmdline+' "'+result+'"')
 			gobject.timeout_add(500, self.check_proximity_sensor)
 
@@ -293,8 +295,8 @@ class Saera:
 		print dir(asr)
 		
 		#Experimental. Custom model for higher accuracy.
-		asr.set_property('lm', 'model/0893.lm')
-		asr.set_property('dict', 'model/0893.dic')
+		asr.set_property('lm', 'model/3204.lm')
+		asr.set_property('dict', 'model/3204.dic')
 
 		bus = self.pipeline.get_bus()
 		bus.add_signal_watch()
