@@ -87,4 +87,4 @@ weekdays = ['sunday','monday','tuesday','wednesday', 'thursday','friday','saturd
 
 # Items
 food = ['pizza', 'pasta', 'sushi', 'falafel', 'bagels', 'burger', 'veggie burger', 'hoagie',
-		'sub', 'sandwich', 'grinder', 'barbeque']
\ No newline at end of file
+		'sub', 'sandwich', 'grinder', 'barbeque', 'food']
\ No newline at end of file
